import React, { useEffect, useState } from 'react';
import { 
  Container, 
  Button, 
  TextField, 
  Table, 
  TableBody, 
  TableCell, 
  TableContainer, 
  TableHead, 
  TableRow,
  Alert,
  CircularProgress
} from '@mui/material';
import { Delete as DeleteIcon } from '@mui/icons-material';
import { Link as RouterLink } from 'react-router-dom';
import { PRIMARY_COLOR, SECONDARY_COLOR } from '../App';
import { useApiCall } from './hooks/useApiCall';
import { api } from '../services/api';

export default function Boxes({ token }) {
  const [boxes, setBoxes] = useState([]);
  const [newBoxName, setNewBoxName] = useState('');

  const { execute: fetchBoxes, loading: loadingBoxes, error: boxesError } = useApiCall();
  const { execute: createBox, loading: creatingBox, error: createError } = useApiCall();
  const { execute: deleteBox, loading: deletingBox, error: deleteError } = useApiCall();

  useEffect(() => {
    const getBoxes = async () => {
      try {
        const response = await fetchBoxes(() => 
          api.boxes.getAll(token)
        );
        setBoxes(response.data);
      } catch (err) {}
    };
    getBoxes();
  }, [token]); // Remove fetchBoxes from dependencies

  const handleCreateBox = async () => {
    if (!newBoxName.trim()) return;

    try {
      const response = await createBox(() => 
        api.boxes.create(token, { name: newBoxName })
      );
      setBoxes([...boxes, response.data]);
      setNewBoxName('');
    } catch (err) {}
  };

  const handleDeleteBox = async (id) => {
    try {
      await deleteBox(() => 
        api.boxes.delete(token, id)
      );
      setBoxes(boxes.filter(box => box.ID !== id));
    } catch (err) {}
  };

  return (
    <Container>
      {(boxesError || createError || deleteError) && (
        <Alert severity="error" sx={{ mb: 2 }}>
          {boxesError?.message || createError?.message || deleteError?.message}
        </Alert>
      )}

      {loadingBoxes ? (
        <CircularProgress />
      ) : (
        <TableContainer>
          <Table size="small">
            <TableHead>
              <TableRow>
                <TableCell>Box Name</TableCell>
                <TableCell>Actions</TableCell>
              </TableRow>
            </TableHead>
            <TableBody>
              {boxes.map((box) => (
                <TableRow key={box.ID}>
                  <TableCell>
                    <RouterLink to={`/api/v1/boxes/${box.ID}/items`} state={{ boxName: box.name, boxID: box.ID }}>
                      {box.name}
                    </RouterLink>
                  </TableCell>
                  <TableCell>
                    <Button 
                      onClick={() => handleDeleteBox(box.ID)} 
                      startIcon={<DeleteIcon />}
                      disabled={deletingBox}
                    >
                      {deletingBox ? <CircularProgress size={20} /> : 'Delete'}
                    </Button>
                  </TableCell>
                </TableRow>
              ))}
            </TableBody>
          </Table>
        </TableContainer>
      )}

      <TextField
        label="New Box"
        variant="outlined"
        fullWidth
        value={newBoxName}
        onChange={(e) => setNewBoxName(e.target.value)}
        disabled={creatingBox}
      />
      <Button 
        sx={{ backgroundColor: PRIMARY_COLOR, borderBottom: '1px solid', borderColor: '#444', color: SECONDARY_COLOR }} 
        variant="contained" 
        onClick={handleCreateBox}
        disabled={creatingBox || !newBoxName.trim()}
      >
        {creatingBox ? <CircularProgress size={24} /> : 'Add Box'}
      </Button>
    </Container>
  );
}