import React from 'react';
import { Alert, Button, Container } from '@mui/material';

class ErrorBoundary extends React.Component {
  constructor(props) {
    super(props);
    this.state = { hasError: false, error: null };
  }

  static getDerivedStateFromError(error) {
    return { hasError: true, error };
  }

  render() {
    if (this.state.hasError) {
      return (
        <Container>
          <Alert severity="error" sx={{ mt: 2 }}>
            Something went wrong
            <Button 
              onClick={() => window.location.reload()}
              variant="outlined" 
              size="small"
              sx={{ ml: 2 }}
            >
              Reload Page
            </Button>
          </Alert>
        </Container>
      );
    }
    return this.props.children;
  }
}

export default ErrorBoundary;