// src/components/Login.js
import React, { useState } from 'react';
import { Button, TextField, Container, Typography, Alert, CircularProgress } from '@mui/material';
import { useNavigate } from 'react-router-dom';
import { PRIMARY_COLOR, SECONDARY_COLOR } from '../App';
import { api } from '../services/api';
import { useApiCall } from './hooks/useApiCall';

export default function Login({ setToken }) {
  const [username, setUsername] = useState('');
  const [password, setPassword] = useState('');
  const navigate = useNavigate();
  const { execute, loading, error } = useApiCall();

  const handleLogin = async (e) => {
    e.preventDefault();
    try {
      const response = await execute(() => api.login({ username, password }));
      setToken(response.data.token);
      navigate('/boxes');
    } catch (err) {
      // Error handling is now managed by useApiCall
      console.error('Login attempt failed');
    }
  };

  return (
    <Container maxWidth="xs">
      <Typography variant="h4" gutterBottom>Login</Typography>

      {error && (
        <Alert severity="error">
          {error.status === 401 ? 'Invalid username or password' : error.message}
        </Alert>
      )}

      <form onSubmit={handleLogin}>
        <TextField
          label="Username"
          variant="outlined"
          fullWidth
          margin="normal"
          value={username}
          onChange={(e) => setUsername(e.target.value)}
        />
        <TextField
          label="Password"
          type="password"
          variant="outlined"
          fullWidth
          margin="normal"
          value={password}
          onChange={(e) => setPassword(e.target.value)}
        />
        <Button 
          sx={{ backgroundColor: PRIMARY_COLOR, borderBottom: '1px solid', borderColor: '#444', color: SECONDARY_COLOR }} 
          variant="contained" 
          color="primary" 
          type="submit" 
          fullWidth
          disabled={loading}
        >
          {loading ? <CircularProgress size={24} /> : 'Login'}
        </Button>
      </form>
    </Container>
  );
}