// src/utils/errorHandler.js
import axios from 'axios';

export class ApiError extends Error {
    constructor(message, status, details = {}) {
      super(message);
      this.status = status;
      this.details = details;
    }
  }
  
  // Enhanced API client with error handling
  export const createApiClient = () => {
    const client = axios.create({
      baseURL: process.env.REACT_APP_API_URL
    });
  
    client.interceptors.response.use(
      response => response,
      error => {
        if (error.response?.status === 401) {
          localStorage.removeItem('token');
          window.location.href = '/login';
          return Promise.reject(new ApiError('Session expired', 401));
        }
        
        return Promise.reject(new ApiError(
          error.response?.data?.message || 'An error occurred',
          error.response?.status,
          error.response?.data
        ));
      }
    );
  
    return client;
  };
